@@ -16,8 +16,8 @@ user_pref("browser.search.param.yahoo-fr", "linuxmint");
 
 // Set the UserAgent
 user_pref("general.useragent.vendor", "Linux Mint");
-user_pref("general.useragent.vendorSub", "17.1");
-user_pref("general.useragent.vendorComment", "Rebecca");
+user_pref("general.useragent.vendorSub", "17.2");
+user_pref("general.useragent.vendorComment", "Rafaela");
 
 // Default search engine
 user_pref("browser.search.order.1", "Yahoo");
@@ -38,7 +38,15 @@ user_pref("network.dns.disableIPv6", true);
 user_pref("browser.startup.homepage_override.mstone", "ignore");
 
 // Homepage
-user_pref("browser.startup.homepage", "http://www.linuxmint.com/start/rebecca");
+user_pref("browser.startup.homepage", "http://www.linuxmint.com/start/rafaela");
+
+// Don't interrupt user workflow
+user_pref('datareporting.policy.dataSubmissionPolicyBypassNotification', true);
+user_pref('browser.slowStartup.notificationDisabled', true);
+user_pref('browser.disableResetPrompt', true);
+user_pref("browser.rights.3.shown", true);
+user_pref("toolkit.telemetry.prompted", 2);
+user_pref("toolkit.telemetry.rejected", true);
 
 // apturl
 user_pref("network.protocol-handler.app.apt",  "/usr/bin/apturl");
