@@ -24,8 +24,8 @@ pref("browser.search.param.yahoo-fr", "linuxmint");
 
 // Set the UserAgent
 pref("general.useragent.vendor", "Linux Mint");
-pref("general.useragent.vendorSub", "17.1");
-pref("general.useragent.vendorComment", "Rebecca");
+pref("general.useragent.vendorSub", "17.2");
+pref("general.useragent.vendorComment", "Rafaela");
 
 // Default search engine
 pref("browser.search.searchEnginesURL", "http://www.linuxmint.com/searchengines/");
@@ -39,6 +39,14 @@ pref("network.dns.disableIPv6", true);
 // Ignore Mozilla release notes startup pages
 pref("browser.startup.homepage_override.mstone", "ignore");
 
+// Don't interrupt user workflow
+pref('datareporting.policy.dataSubmissionPolicyBypassNotification', true);
+pref('browser.slowStartup.notificationDisabled', true);
+pref('browser.disableResetPrompt', true);
+pref("browser.rights.3.shown", true);
+pref("toolkit.telemetry.prompted", 2);
+pref("toolkit.telemetry.rejected", true);
+
 // identify default locale to use if no /usr/lib/firefox-addons/searchplugins/LOCALE
 // exists for the current used LOCALE
 pref("distribution.searchplugins.defaultLocale", "en-US");
